\name{radialDistortedToUndistortedOpenCV}
\alias{radialDistortedToUndistortedOpenCV}
\title{Converts distorted coords to undistorted coords using OpenCV model.}
\usage{
  radialDistortedToUndistortedOpenCV(i_pts, k1, k2, k3, p1,
    p2, cx, cy, fx, fy, cxscale = cx, cyscale = cy,
    fxscale = fx, fyscale = fy, one.based.input = FALSE,
    one.based.output = FALSE, iters = 5, scale.back = T)
}
\arguments{
  \item{i_pts}{input points, distorted.}

  \item{iters}{number of iterations to perform.}

  \item{scale.back}{whether to scale the coords back to
  camera-specific cords or leave in normalised. For
  internal use only.}

  \item{one.based.input}{boolean, whether input coords are
  1-based or 0-based. Default 0-based.}

  \item{one.based.output}{boolean, whether output coords
  are to be 1-based or 0-based. Default 0-based.}

  \item{k1}{radial distortion parameter, barrel distort/r^2
  coeffient (see details)}

  \item{k2}{radial distortion parameter, r^4 coefficient
  (see details)}

  \item{k3}{radial distortion parameter, r^6 coefficient
  (see details); often 0 unless calculated from many images
  (otherwise can introduce more noise than it corrects)}

  \item{p1}{tangential distortion parameter (see details);
  default 0}

  \item{p2}{tangential distortion parameter (see details);
  default 0}

  \item{cx}{x-centre of image; usually (nx-1)/2}

  \item{cy}{y-centre of image; usually (ny-1)/2}

  \item{fx}{focal length in terms of pixels; f (mm) *
  scale_x (px/mm)}

  \item{fy}{focal length in terms of pixels; f (mm) *
  scale_y (px/mm)}

  \item{cxscale}{x-centre of image with scale (see
  details); if larger than cx the original image will be
  shrunk and more distortion will show. default cx.}

  \item{cyscale}{y-centre of image with scale (see
  details); default cy.}

  \item{fxscale}{normalisation factor for x coords in
  output image (see details); default fx}

  \item{fyscale}{normalisation factor for y coords in
  output image (see details); default fy}
}
\value{
  pts_d undistorted pixel coords (not necessarily integers)
  corresponding to the input ones.  It is up to the user to
  interpolate them. Matrix, 2x[npoints].
}
\description{
  Converts distorted coords to undistorted coords using
  OpenCV model.
}
\details{
  Given undistorted image coords and distortion parameters,
  returns the corresponding image coords in the distorted
  image. Parrots openCV model [eqn (1) in details].
}
\section{History}{
  v1.0 (9-11-2011)
}
\references{
  OpenCV function cv2.undistortPoints
  http://opencv.itseez.com/modules/imgproc/doc/geometric_transformations.html?highlight=undistort#undistortpoints
}
\seealso{
  Other radialDistortion: \code{\link{fullaParameters}},
  \code{\link{openCVParameters}},
  \code{\link{radialDistortedToUndistortedFulla}},
  \code{\link{radialUndistortedToDistortedFulla}},
  \code{\link{radialUndistortedToDistortedOpenCV}},
  \code{\link{rLensDistortion}},
  \code{\link{unRadialDistortFulla}},
  \code{\link{unRadialDistortOpenCV}}
}

