\name{unRadialDistortFulla}
\alias{unRadialDistortFulla}
\title{removes radial distortion from an image using Fulla/Hugin model.
Given an image and parameters a,b,c,d,e,f :
 un-distorts an image that has been barrel distorted,
 using the same model/algorithm as FULLA (command line prog)}
\usage{
  unRadialDistortFulla(imgPath, a = 0, b = 0, c = 0,
    d = 1 - a - b - c, e = 0, f = 0, defaultValue = 0)
}
\arguments{
  \item{imgPath}{image file name to be corrected}

  \item{defaultValue}{the value of pixels that have no
  mapping in the original image (default black)}

  \item{a}{parameter for distortion polynomial, r^3 term
  (see details)}

  \item{b}{parameter for distortion polynomial, barrel
  distort/r^2 term (see details)}

  \item{c}{parameter for distortion polynomial, r term (see
  details)}

  \item{d}{parameter for distortion polynomial, scaling
  term (see details)}

  \item{e}{the x shift of optical centre in the image
  Default image centre, leave if you don't know.}

  \item{f}{the y shift of optical centre in the image
  Default image centre, leave if you don't know.}
}
\description{
  removes radial distortion from an image using Fulla/Hugin
  model. Given an image and parameters a,b,c,d,e,f :
  un-distorts an image that has been barrel distorted,
  using the same model/algorithm as FULLA (command line
  prog)
}
\details{
  Hugin/Panotools uses the model

  [xy]_{distorted} = [xy](d + cr + br^2 + ar^3), ----------
  (1)

  where r is the location of a point in the
  UNdistorted/corrected image, being the normalised radius
  from the image centre.  Also, d is often chosen to be
  1-a-b-c, as this preserves image size: when r = 1, then
  the distorted r is also 1.

  The normalised radius is such that the largest circle
  fitting entirely in the image has r=1.

  That is, given a (0-based) pixel index (x,y) in the
  distorted/uncorrected image, one calculates the radius r
  by:

  c_x <- width/2 # location of image centre before shifting
  c_y <- height/2

  x_shifted <- x - c_x - e + 0.5 # add 0.5 because of
  centre/edge of pixel thing.  y_shifted <- y - c_y - f +
  0.5

  R <- MIN( width/2, height/2 ) r <- sqrt( x_shifted^2 +
  y_shifted^2 ) / R

  k <- (d + cr + br^2 + ar^3) # scale factor

  xd <- k*x_shifted + c_x + e - 0.5 # scale by k and shift
  back.  yd <- k*y_shifted + c_y + f - 0.5

  Then the intensity at location (x,y) in the undistorted
  image should be the intensity at location (xd,yd) in the
  distorted image.  Interpolate it how you will.
}
\section{History}{
  v1.1 (7-11-2011_ - added documentation v1.0 (5-7-2011)
}
\references{
  For the model, fulla source is incredibly helpful, and
  also the sites
  http://wiki.panotools.org/Lens_Correction_in_PanoTools
  http://wiki.panotools.org/Lens_correction_model

  Someone has implemented these in Matlab (slightly
  different method???)
  http://staff.science.uva.nl/~iesteban/

  For a way to determine a,b,c,d you need to have some sort
  of calibration image with known straight lines in it,
  then select points on that line, and basically optimise
  equation (1) with respect to a,b,c,d so that the
  undistorted line is straight.

  Hugin is a useful tool for doing this, you essentially
  pick points on straight lines and optimise with respect
  to a,b,c only (some call for y,p,r first, then a,b,c ?)
  I only optimised w.r.t. b so far (that is the parameter
  that corresponds directly to barrel distortion).

  NOTE: put d = 1 - a - b - c? this means that when r=1,
  r_dist = 1 -- preserves image size.
}
\seealso{
  Other radialDistortion: \code{\link{fullaParameters}},
  \code{\link{openCVParameters}},
  \code{\link{radialDistortedToUndistortedFulla}},
  \code{\link{radialDistortedToUndistortedOpenCV}},
  \code{\link{radialUndistortedToDistortedFulla}},
  \code{\link{radialUndistortedToDistortedOpenCV}},
  \code{\link{rLensDistortion}},
  \code{\link{unRadialDistortOpenCV}}
}

